@@ -14,10 +14,13 @@ import importlib
 import importlib.util
 import os
 import logging
+import re
+import keyword
 
 # Framework-specific imports with availability checks
 CREWAI_AVAILABLE = False
 AUTOGEN_AVAILABLE = False
+AUTOGEN_V4_AVAILABLE = False
 PRAISONAI_TOOLS_AVAILABLE = False
 AGENTOPS_AVAILABLE = False
 PRAISONAI_AVAILABLE = False
@@ -41,6 +44,17 @@ try:
 except ImportError:
     pass
 
+try:
+    from autogen_agentchat.agents import AssistantAgent as AutoGenV4AssistantAgent
+    from autogen_ext.models.openai import OpenAIChatCompletionClient
+    from autogen_agentchat.teams import RoundRobinGroupChat
+    from autogen_agentchat.conditions import TextMentionTermination, MaxMessageTermination
+    from autogen_agentchat.messages import TextMessage
+    from autogen_core import CancellationToken
+    AUTOGEN_V4_AVAILABLE = True
+except ImportError:
+    pass
+
 try:
     import agentops
     AGENTOPS_AVAILABLE = True
@@ -70,6 +84,40 @@ os.environ["OTEL_SDK_DISABLED"] = "true"
 def noop(*args, **kwargs):
     pass
 
+def sanitize_agent_name_for_autogen_v4(name):
+    """
+    Sanitize agent name to be a valid Python identifier for AutoGen v0.4.
+    
+    Args:
+        name (str): The original agent name
+        
+    Returns:
+        str: A valid Python identifier
+    """
+    # Convert to string and replace invalid characters with underscores
+    sanitized = re.sub(r'[^a-zA-Z0-9_]', '_', str(name))
+    
+    # Collapse only very excessive underscores (5 or more) to reduce extreme cases
+    sanitized = re.sub(r'_{5,}', '_', sanitized)
+    
+    # Remove trailing underscores only if not part of a dunder pattern and only if singular
+    if sanitized.endswith('_') and not sanitized.endswith('__') and sanitized != '_':
+        sanitized = sanitized.rstrip('_')
+    
+    # Ensure it starts with a letter or underscore (not a digit)
+    if sanitized and sanitized[0].isdigit():
+        sanitized = 'agent_' + sanitized
+    
+    # Handle empty string or only invalid characters (including single underscore from all invalid chars)
+    if not sanitized or sanitized == '_':
+        sanitized = 'agent'
+    
+    # Check if it's a Python keyword and append underscore if so
+    if keyword.iskeyword(sanitized):
+        sanitized += '_'
+    
+    return sanitized
+
 def disable_crewai_telemetry():
     if CREWAI_AVAILABLE:
         for attr in dir(Telemetry):
@@ -123,8 +171,8 @@ class AgentsGenerator:
         # Validate framework availability
         if framework == "crewai" and not CREWAI_AVAILABLE:
             raise ImportError("CrewAI is not installed. Please install it with 'pip install praisonai[crewai]'")
-        elif framework == "autogen" and not AUTOGEN_AVAILABLE:
-            raise ImportError("AutoGen is not installed. Please install it with 'pip install praisonai[autogen]'")
+        elif framework == "autogen" and not (AUTOGEN_AVAILABLE or AUTOGEN_V4_AVAILABLE):
+            raise ImportError("AutoGen is not installed. Please install it with 'pip install praisonai[autogen]' for v0.2 or 'pip install praisonai[autogen-v4]' for v0.4")
         elif framework == "praisonai" and not PRAISONAI_AVAILABLE:
             raise ImportError("PraisonAI is not installed. Please install it with 'pip install praisonaiagents'")
 
@@ -316,11 +364,35 @@ class AgentsGenerator:
         framework = self.framework or config.get('framework')
 
         if framework == "autogen":
-            if not AUTOGEN_AVAILABLE:
-                raise ImportError("AutoGen is not installed. Please install it with 'pip install praisonai[autogen]'")
+            if not (AUTOGEN_AVAILABLE or AUTOGEN_V4_AVAILABLE):
+                raise ImportError("AutoGen is not installed. Please install it with 'pip install praisonai[autogen]' for v0.2 or 'pip install praisonai[autogen-v4]' for v0.4")
+            
+            # Choose autogen version based on availability and environment preference
+            # AUTOGEN_VERSION can be set to "v0.2" or "v0.4" to force a specific version
+            autogen_version = os.environ.get("AUTOGEN_VERSION", "auto").lower()
+            
+            use_v4 = False
+            if autogen_version == "v0.4" and AUTOGEN_V4_AVAILABLE:
+                use_v4 = True
+            elif autogen_version == "v0.2" and AUTOGEN_AVAILABLE:
+                use_v4 = False
+            elif autogen_version == "auto":
+                # Default preference: use v0.4 if available, fallback to v0.2
+                use_v4 = AUTOGEN_V4_AVAILABLE
+            else:
+                # Fallback to whatever is available
+                use_v4 = AUTOGEN_V4_AVAILABLE and not AUTOGEN_AVAILABLE
+            
             if AGENTOPS_AVAILABLE:
-                agentops.init(os.environ.get("AGENTOPS_API_KEY"), default_tags=["autogen"])
-            return self._run_autogen(config, topic, tools_dict)
+                version_tag = "autogen-v4" if use_v4 else "autogen-v2"
+                agentops.init(os.environ.get("AGENTOPS_API_KEY"), default_tags=[version_tag])
+            
+            if use_v4:
+                self.logger.info("Using AutoGen v0.4")
+                return self._run_autogen_v4(config, topic, tools_dict)
+            else:
+                self.logger.info("Using AutoGen v0.2")
+                return self._run_autogen(config, topic, tools_dict)
         elif framework == "praisonai":
             if not PRAISONAI_AVAILABLE:
                 raise ImportError("PraisonAI is not installed. Please install it with 'pip install praisonaiagents'")
@@ -407,6 +479,113 @@ class AgentsGenerator:
             
         return result
 
+    def _run_autogen_v4(self, config, topic, tools_dict):
+        """
+        Run agents using the AutoGen v0.4 framework with async, event-driven architecture.
+        
+        Args:
+            config (dict): Configuration dictionary
+            topic (str): The topic to process
+            tools_dict (dict): Dictionary of available tools
+            
+        Returns:
+            str: Result of the agent interactions
+        """
+        import asyncio
+        
+        async def run_autogen_v4_async():
+            # Create model client for v0.4
+            model_config = self.config_list[0] if self.config_list else {}
+            model_client = OpenAIChatCompletionClient(
+                model=model_config.get('model', 'gpt-4o'),
+                api_key=model_config.get('api_key', os.environ.get("OPENAI_API_KEY")),
+                base_url=model_config.get('base_url', "https://api.openai.com/v1")
+            )
+            
+            agents = []
+            combined_tasks = []
+            
+            # Create agents from config
+            for role, details in config['roles'].items():
+                # For AutoGen v0.4, ensure agent name is a valid Python identifier
+                agent_name = details['role'].format(topic=topic).replace("{topic}", topic)
+                agent_name = sanitize_agent_name_for_autogen_v4(agent_name)
+                backstory = details['backstory'].format(topic=topic)
+                
+                # Convert tools for v0.4 - simplified tool passing
+                agent_tools = []
+                for tool_name in details.get('tools', []):
+                    if tool_name in tools_dict:
+                        tool_instance = tools_dict[tool_name]
+                        # For v0.4, we can pass the tool's run method directly if it's callable
+                        if hasattr(tool_instance, 'run') and callable(tool_instance.run):
+                            agent_tools.append(tool_instance.run)
+                
+                # Create v0.4 AssistantAgent
+                assistant = AutoGenV4AssistantAgent(
+                    name=agent_name,
+                    system_message=backstory + ". Must reply with 'TERMINATE' when the task is complete.",
+                    model_client=model_client,
+                    tools=agent_tools,
+                    reflect_on_tool_use=True
+                )
+                
+                agents.append(assistant)
+                
+                # Collect all task descriptions for sequential execution
+                for task_name, task_details in details.get('tasks', {}).items():
+                    description_filled = task_details['description'].format(topic=topic)
+                    combined_tasks.append(description_filled)
+            
+            if not agents:
+                return "No agents created from configuration"
+            
+            # Create termination conditions
+            text_termination = TextMentionTermination("TERMINATE")
+            max_messages_termination = MaxMessageTermination(max_messages=20)
+            termination_condition = text_termination | max_messages_termination
+            
+            # Create RoundRobinGroupChat for parallel/sequential execution
+            group_chat = RoundRobinGroupChat(
+                agents,
+                termination_condition=termination_condition,
+                max_turns=len(agents) * 3  # Allow multiple rounds
+            )
+            
+            # Combine all tasks into a single task description
+            task_description = f"Topic: {topic}\n\nTasks to complete:\n" + "\n".join(
+                f"{i+1}. {task}" for i, task in enumerate(combined_tasks)
+            )
+            
+            # Run the group chat
+            try:
+                result = await group_chat.run(task=task_description)
+                
+                # Extract the final message content
+                if result.messages:
+                    final_message = result.messages[-1]
+                    if hasattr(final_message, 'content'):
+                        return f"### AutoGen v0.4 Output ###\n{final_message.content}"
+                    else:
+                        return f"### AutoGen v0.4 Output ###\n{str(final_message)}"
+                else:
+                    return "### AutoGen v0.4 Output ###\nNo messages generated"
+                    
+            except Exception as e:
+                self.logger.error(f"Error in AutoGen v0.4 execution: {str(e)}")
+                return f"### AutoGen v0.4 Error ###\n{str(e)}"
+            
+            finally:
+                # Close the model client
+                await model_client.close()
+        
+        # Run the async function
+        try:
+            return asyncio.run(run_autogen_v4_async())
+        except Exception as e:
+            self.logger.error(f"Error running AutoGen v0.4: {str(e)}")
+            return f"### AutoGen v0.4 Error ###\n{str(e)}"
+
     def _run_crewai(self, config, topic, tools_dict):
         """
         Run agents using the CrewAI framework.
@@ -437,7 +616,7 @@ class AgentsGenerator:
             llm_model = details.get('llm')
             if llm_model:
                 llm = PraisonAIModel(
-                    model=llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o",
+                    model=llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
                     base_url=self.config_list[0].get('base_url') if self.config_list else None,
                     api_key=self.config_list[0].get('api_key') if self.config_list else None
                 ).get_model()
@@ -451,7 +630,7 @@ class AgentsGenerator:
             function_calling_llm_model = details.get('function_calling_llm')
             if function_calling_llm_model:
                 function_calling_llm = PraisonAIModel(
-                    model=function_calling_llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o",
+                    model=function_calling_llm_model.get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
                     base_url=self.config_list[0].get('base_url') if self.config_list else None,
                     api_key=self.config_list[0].get('api_key') if self.config_list else None
                 ).get_model()
@@ -567,8 +746,8 @@ class AgentsGenerator:
                 backstory=backstory_filled,
                 tools=tools_list,  # Pass the entire tools list to the agent
                 allow_delegation=details.get('allow_delegation', False),
-                llm=details.get('llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o",
-                function_calling_llm=details.get('function_calling_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o",
+                llm=details.get('llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
+                function_calling_llm=details.get('function_calling_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
                 max_iter=details.get('max_iter', 15),
                 max_rpm=details.get('max_rpm'),
                 max_execution_time=details.get('max_execution_time'),
@@ -577,7 +756,7 @@ class AgentsGenerator:
                 system_template=details.get('system_template'),
                 prompt_template=details.get('prompt_template'),
                 response_template=details.get('response_template'),
-                reflect_llm=details.get('reflect_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o",
+                reflect_llm=details.get('reflect_llm', {}).get("model") or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
                 min_reflect=details.get('min_reflect', 1),
                 max_reflect=details.get('max_reflect', 3),
             )
@@ -633,7 +812,7 @@ class AgentsGenerator:
                 tasks=tasks,
                 verbose=True,
                 process="hierarchical",
-                manager_llm=config.get('manager_llm') or os.environ.get("MODEL_NAME") or "openai/gpt-4o",
+                manager_llm=config.get('manager_llm') or os.environ.get("MODEL_NAME") or "openai/gpt-4o-mini",
                 memory=memory
             )
         else:
