@@ -32,6 +32,13 @@ try:
 except ImportError:
     pass
 
+try:
+    from autogen_agentchat.agents import AssistantAgent
+    from autogen_ext.models.openai import OpenAIChatCompletionClient
+    AUTOGEN_V4_AVAILABLE = True
+except ImportError:
+    AUTOGEN_V4_AVAILABLE = False
+
 try:
     from praisonai_tools import (
         CodeDocsSearchTool, CSVSearchTool, DirectorySearchTool, DOCXSearchTool,
@@ -73,10 +80,11 @@ class AutoGenerator:
 CrewAI is not installed. Please install with:
     pip install "praisonai[crewai]"
 """)
-        elif framework == "autogen" and not AUTOGEN_AVAILABLE:
+        elif framework == "autogen" and not (AUTOGEN_AVAILABLE or AUTOGEN_V4_AVAILABLE):
             raise ImportError("""
 AutoGen is not installed. Please install with:
-    pip install "praisonai[autogen]"
+    pip install "praisonai[autogen]" for v0.2
+    pip install "praisonai[autogen-v4]" for v0.4
 """)
         elif framework == "praisonai" and not PRAISONAI_AVAILABLE:
             raise ImportError("""
@@ -86,14 +94,21 @@ Praisonai is not installed. Please install with:
 
         # Only show tools message if using a framework and tools are needed
         if (framework in ["crewai", "autogen"]) and not PRAISONAI_TOOLS_AVAILABLE:
-            logging.warning(f"""
+            if framework == "autogen":
+                logging.warning("""
+Tools are not available for autogen. To use tools, install:
+    pip install "praisonai[autogen]" for v0.2
+    pip install "praisonai[autogen-v4]" for v0.4
+""")
+            else:
+                logging.warning(f"""
 Tools are not available for {framework}. To use tools, install:
     pip install "praisonai[{framework}]"
 """)
 
         # Support multiple environment variable patterns for better compatibility
         # Priority order: MODEL_NAME > OPENAI_MODEL_NAME for model selection
-        model_name = os.environ.get("MODEL_NAME") or os.environ.get("OPENAI_MODEL_NAME", "gpt-4o")
+        model_name = os.environ.get("MODEL_NAME") or os.environ.get("OPENAI_MODEL_NAME", "gpt-4o-mini")
         
         # Priority order for base_url: OPENAI_BASE_URL > OPENAI_API_BASE > OLLAMA_API_BASE
         # OPENAI_BASE_URL is the standard OpenAI SDK environment variable
