@@ -16,7 +16,7 @@ logging.basicConfig(level=os.environ.get('LOGLEVEL', 'INFO').upper(), format='%(
 framework = "crewai"
 config_list = [
             {
-                'model': os.environ.get("OPENAI_MODEL_NAME", "gpt-4o"),
+                'model': os.environ.get("OPENAI_MODEL_NAME", "gpt-4o-mini"),
                 'base_url': os.environ.get("OPENAI_API_BASE", "https://api.openai.com/v1"),
                 'api_key': os.environ.get("OPENAI_API_KEY", "")
             }
