@@ -124,7 +124,7 @@ class PraisonAI:
         # Create config_list with AutoGen compatibility
         # Support multiple environment variable patterns for better compatibility
         # Priority order: MODEL_NAME > OPENAI_MODEL_NAME for model selection
-        model_name = os.environ.get("MODEL_NAME") or os.environ.get("OPENAI_MODEL_NAME", "gpt-4o")
+        model_name = os.environ.get("MODEL_NAME") or os.environ.get("OPENAI_MODEL_NAME", "gpt-4o-mini")
         
         # Priority order for base_url: OPENAI_BASE_URL > OPENAI_API_BASE > OLLAMA_API_BASE
         # OPENAI_BASE_URL is the standard OpenAI SDK environment variable
@@ -545,7 +545,7 @@ class PraisonAI:
             return default_args
         
         # Define special commands
-        special_commands = ['chat', 'code', 'call', 'realtime', 'train', 'ui']
+        special_commands = ['chat', 'code', 'call', 'realtime', 'train', 'ui', 'context']
         
         parser = argparse.ArgumentParser(prog="praisonai", description="praisonAI command-line interface")
         parser.add_argument("--framework", choices=["crewai", "autogen", "praisonai"], help="Specify the framework")
@@ -569,6 +569,9 @@ class PraisonAI:
         parser.add_argument("--merge", action="store_true", help="Merge existing agents.yaml with auto-generated agents instead of overwriting")
         parser.add_argument("--claudecode", action="store_true", help="Enable Claude Code integration for file modifications and coding tasks")
         parser.add_argument("--file", "-f", type=str, help="Read input from a file and append it to the prompt")
+        parser.add_argument("--url", type=str, help="Repository URL for context analysis")
+        parser.add_argument("--goal", type=str, help="Goal for context engineering")
+        parser.add_argument("--auto-analyze", action="store_true", help="Enable automatic analysis in context engineering")
         
         # If we're in a test environment, parse with empty args to avoid pytest interference
         if in_test_env:
@@ -674,6 +677,25 @@ class PraisonAI:
                 self.create_chainlit_interface()
                 sys.exit(0)
 
+            elif args.command == 'context':
+                if not PRAISONAI_AVAILABLE:
+                    print("[red]ERROR: PraisonAI Agents is not installed. Install with:[/red]")
+                    print("\npip install praisonaiagents\n")
+                    sys.exit(1)
+                
+                if not args.url:
+                    print("[red]ERROR: --url is required for context command[/red]")
+                    print("Usage: praisonai context --url <repository_url> --goal <goal> [--auto-analyze]")
+                    sys.exit(1)
+                
+                if not args.goal:
+                    print("[red]ERROR: --goal is required for context command[/red]")
+                    print("Usage: praisonai context --url <repository_url> --goal <goal> [--auto-analyze]")
+                    sys.exit(1)
+                
+                self.handle_context_command(args.url, args.goal, getattr(args, 'auto_analyze', False))
+                sys.exit(0)
+
         # Only check framework availability for agent-related operations
         if not args.command and (args.init or args.auto or args.framework):
             if not CREWAI_AVAILABLE and not AUTOGEN_AVAILABLE and not PRAISONAI_AVAILABLE:
@@ -867,6 +889,50 @@ class PraisonAI:
         else:
             print("ERROR: Realtime UI is not installed. Please install it with 'pip install \"praisonai[realtime]\"' to use the realtime UI.")
 
+    def handle_context_command(self, url: str, goal: str, auto_analyze: bool = False) -> str:
+        """
+        Handle the context command by creating a ContextAgent and running it.
+        
+        Args:
+            url: Repository URL for context analysis
+            goal: Goal for context engineering
+            auto_analyze: Enable automatic analysis (default: False)
+            
+        Returns:
+            str: Result from context engineering
+        """
+        try:
+            from praisonaiagents import ContextAgent
+            print("[bold green]Starting Context Engineering...[/bold green]")
+            print(f"URL: {url}")
+            print(f"Goal: {goal}")
+            print(f"Auto-analyze: {auto_analyze}")
+            
+            # Use the same model configuration pattern as other CLI commands
+            # Priority order: MODEL_NAME > OPENAI_MODEL_NAME for model selection
+            model_name = os.environ.get("MODEL_NAME") or os.environ.get("OPENAI_MODEL_NAME", "gpt-4o-mini")
+            
+            # Create ContextAgent with user's LLM configuration
+            agent = ContextAgent(llm=model_name, auto_analyze=auto_analyze)
+            
+            # Format input as expected by the start method: "url goal"
+            input_text = f"{url} {goal}"
+            
+            # Execute the context engineering
+            result = agent.start(input_text)
+            
+            print("\n[bold green]Context Engineering Complete![/bold green]")
+            print(result)
+            return result
+            
+        except ImportError as e:
+            print(f"[red]ERROR: Failed to import ContextAgent: {e}[/red]")
+            print("Make sure praisonaiagents is installed: pip install praisonaiagents")
+            sys.exit(1)
+        except Exception as e:
+            print(f"[red]ERROR: Context engineering failed: {e}[/red]")
+            sys.exit(1)
+
 if __name__ == "__main__":
     praison_ai = PraisonAI()
     praison_ai.main()
